@@ -15,6 +15,12 @@ use crate::half_life::HALF_LIFE          ;
  use crate::particle::DEUTERONMASS       ; 
  use crate::particle::TRITONMASS         ; 
  use crate::particle::NEUTRINOMASS       ;   
+ 
+use Pion::lepton::Lepton;
+use Pion::lepton::AntiLepton;
+use Pion::baryon::Baryon;
+use Pion::baryon::AntiBaryon;
+//use crate::particle::Party;
 
  fn rand()->u64{
    let mut x: u64 = 0;
@@ -189,7 +195,7 @@ match x {
             let particleenergia = totalenergia -(PROTONMASS/self.amu())* totalenergia ; 
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
-             particle_vector.push(Particle::Proton(particleenergia));
+             particle_vector.push(Particle::Baryon( Baryon::Proton(particleenergia) ) );
           } ,
     3  => {                    // 2p
             izotop.0-=2;
@@ -198,8 +204,8 @@ match x {
             let particleenergia = totalenergia -(2.0*PROTONMASS/self.amu())* totalenergia ;   
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
-             particle_vector.push(Particle::Proton(particleenergia/2.0));
-             particle_vector.push(Particle::Proton(particleenergia/2.0));
+             particle_vector.push(Particle::Baryon( Baryon::Proton(particleenergia/2.0) ));
+             particle_vector.push(Particle::Baryon( Baryon::Proton(particleenergia/2.0) ));
           } ,
     4  => {          // n 
                   izotop.1-=1;
@@ -208,7 +214,7 @@ match x {
             let particleenergia = totalenergia -(NEUTRONMASS/self.amu())* totalenergia ; 
             energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
-             particle_vector.push(Particle::Neutron(particleenergia));            
+             particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia) ));            
           } ,
     5  => {          // 2n 
                   izotop.1-=2;
@@ -217,8 +223,8 @@ match x {
             let particleenergia = totalenergia -(2.0*NEUTRONMASS/self.amu())* totalenergia ;
              energia = totalenergia-particleenergia;
              self.change(daughter.nuclide_index());
-             particle_vector.push(Particle::Neutron(particleenergia/2.0));
-             particle_vector.push(Particle::Neutron(particleenergia/2.0));       
+             particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));
+             particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));       
           }      
     6  => {        println!("6");            // Electron capture
                   izotop.0-=1; izotop.1+=1;
@@ -227,7 +233,7 @@ match x {
             let particleenergia = totalenergia -(NEUTRINOMASS/self.amu())* totalenergia ;
             energia = totalenergia-particleenergia;
             self.change(daughter.nuclide_index());
-            particle_vector.push(Particle::Neutrino(particleenergia));
+            particle_vector.push(Particle::Lepton( Lepton::ElectronNeutrino(particleenergia) ));
           } ,
     7  => {            // Double Electron Capture
                   izotop.0-=2; izotop.1+=2;
@@ -236,19 +242,19 @@ match x {
             let particleenergia = totalenergia -(2.0*NEUTRINOMASS/self.amu())* totalenergia ;
             energia = totalenergia-particleenergia;
             self.change(daughter.nuclide_index());
-            particle_vector.push(Particle::Neutrino(particleenergia/2.0));
-            particle_vector.push(Particle::Neutrino(particleenergia/2.0));
+            particle_vector.push(Particle::Lepton( Lepton::ElectronNeutrino(particleenergia/2.0) ));
+            particle_vector.push(Particle::Lepton( Lepton::ElectronNeutrino(particleenergia/2.0) ));
           } , 
-    8  => {                    // B-p
+    8  => {                    // B-p  particleenergia*2.35E-7*ELECTRONMASS
             izotop.1-=1; 
             let daughter= Nuclide::assign(nucleons_nuclide(&izotop) );
             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+PROTONMASS)/self.amu())* totalenergia ;   
             let protonenergia  = particleenergia - particleenergia*2.35E-7;
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Proton(protonenergia));
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));  
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia) ) );
+            particle_vector.push(Particle::Lepton( Lepton::Electron(particleenergia*(1.0-2.35E-7) ) ));  
+            particle_vector.push(Particle::AntiLepton( AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));  
           } ,      
     9  => {          // Beta +  http://hyperphysics.phy-astr.gsu.edu/hbase/Nuclear/beta2.html#c1
                   izotop.0-=1; izotop.1+=1;
@@ -256,8 +262,8 @@ match x {
             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)/self.amu())* totalenergia ;  
             energia = totalenergia - particleenergia ; 
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7));              
+            particle_vector.push(Particle::AntiLepton( AntiLepton::Electron(particleenergia*(1.0-2.35E-7) ) ));  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7)));              
           } ,
    10  => {            // Double Beta + 
                   izotop.0-=2; izotop.1+=2;
@@ -265,10 +271,10 @@ match x {
             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)*2.0/self.amu())* totalenergia ;  
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)*0.5));  
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)*0.5));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*0.5));
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*0.5));    
+            particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7)*0.5) ) );  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7)*0.5) ) );  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*(1.0-2.35E-7)*0.5) ) );  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*(1.0-2.35E-7)*0.5) ) );  
           } ,
    11  => {           // Beta -
                   izotop.0+=1; izotop.1-=1;
@@ -276,8 +282,8 @@ match x {
             let totalenergia = (self.amu() -daughter.amu())*931.49410242;;
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)/self.amu())* totalenergia ; 
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7));
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7)));
             self.change(daughter.nuclide_index());
           } ,
    12  => {          // Double Beta -
@@ -287,10 +293,10 @@ match x {
             let totalenergia = (self.amu()- daughter.amu())*931.49410242;
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS)*2.0/self.amu())* totalenergia ;  
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)*0.5));  
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)*0.5));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*0.5));
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*0.5));      
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7)*0.5)));  
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7)*0.5)));  
+            particle_vector.push(Particle::AntiLepton( AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));
+            particle_vector.push(Particle::AntiLepton( AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));      
           } ,
    13  => {                    // B- + n 
                   izotop.0+=1; izotop.1-=2; 
@@ -299,9 +305,9 @@ match x {
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+NEUTRONMASS)/self.amu())* totalenergia ;   
             let neutronenergia  = particleenergia - particleenergia*2.35E-7;
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Neutron(neutronenergia));
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));      
+            particle_vector.push(Particle::Baryon(Baryon::Neutron(neutronenergia)));
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));      
           } ,
    14  => {                    // B- + 2n
                   izotop.0+=1; izotop.1-=3; 
@@ -311,10 +317,10 @@ match x {
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+2.0*NEUTRONMASS)/self.amu())* totalenergia ;   
             let neutronenergia  = particleenergia - particleenergia*2.35E-7;   
             energia = totalenergia - particleenergia ;       
-            particle_vector.push(Particle::Neutron(neutronenergia/2.0));
-            particle_vector.push(Particle::Neutron(neutronenergia/2.0));            
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));       
+            particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));
+            particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/2.0) ));           
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    15  => {                    // B- + 3n
             izotop.0+=1; izotop.1-=4; 
@@ -323,11 +329,11 @@ match x {
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+3.0*NEUTRONMASS)/self.amu())* totalenergia ;   
             let neutronenergia  = particleenergia - particleenergia*2.35E-7;
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Neutron(neutronenergia/3.0));
-            particle_vector.push(Particle::Neutron(neutronenergia/3.0));      
-            particle_vector.push(Particle::Neutron(neutronenergia/3.0));            
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));       
+            particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/3.0) ));
+            particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/3.0) ));   
+            particle_vector.push(Particle::Baryon( Baryon::Neutron(particleenergia/3.0) ));
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    16  => {                    // B+ + p
             izotop.0-=2; izotop.1+=1;
@@ -336,9 +342,9 @@ match x {
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+PROTONMASS)/self.amu())* totalenergia  ;
             let protonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Proton(protonenergia));    
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*ELECTRONMASS));   
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia) ) );
+            particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    17  => {                    // B+ + 2p
             izotop.0-=3; izotop.1+=1;
@@ -347,10 +353,10 @@ match x {
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+2.0*PROTONMASS)/self.amu())* totalenergia  ;
             let protonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Proton(protonenergia/2.0));  
-            particle_vector.push(Particle::Proton(protonenergia/2.0));      
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*ELECTRONMASS));      
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/2.0) ) );
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/2.0) ) );
+            particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    18  => {                    // B+ + 3p
             izotop.0-=4; izotop.1+=1;
@@ -359,11 +365,11 @@ match x {
             let particleenergia = totalenergia -((ELECTRONMASS+NEUTRINOMASS+3.0*PROTONMASS)/self.amu())* totalenergia;  
             let protonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
-            particle_vector.push(Particle::Proton(protonenergia/3.0));  
-            particle_vector.push(Particle::Proton(protonenergia/3.0));      
-            particle_vector.push(Particle::Proton(protonenergia/3.0));      
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*ELECTRONMASS));       
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/3.0) ) );
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/3.0) ) );
+            particle_vector.push(Particle::Baryon( Baryon::Proton(protonenergia/3.0) ) );
+            particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
                                   
           } ,
    19  => {                    // B- + A 
@@ -374,8 +380,8 @@ match x {
             let alphaenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Alpha(alphaenergia));    
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS))
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    20  => {                    // B+ + A
                   izotop.0-=3; izotop.1-=1;
@@ -385,8 +391,8 @@ match x {
             let alphaenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Alpha(alphaenergia));    
-            particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*ELECTRONMASS));      
+            particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    21  => {                    // B- + Deuteron 
                   izotop.1-=3; 
@@ -396,8 +402,8 @@ match x {
             let deuteronenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Deuteron(deuteronenergia));    
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));            
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    22  => {                    // B- + Triton
                   izotop.1-=4;     
@@ -407,8 +413,8 @@ match x {
             let tritonenergia  = particleenergia - particleenergia*2.35E-7; 
             energia = totalenergia - particleenergia ;
             particle_vector.push(Particle::Triton(tritonenergia));    
-            particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));       
+            particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+            particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    23  => {                    // SF
              let rand = rand()>>54;
@@ -432,9 +438,9 @@ match x {
              let totalenergia = (self.amu()- daughter.amu())*931.49410242;
              let particleenergia = (daughter.amu()/self.amu())* totalenergia ;  
              energia = totalenergia - particleenergia ;
-              particle_vector.push(Particle::Element(decay_particle,particleenergia));
-              particle_vector.push(Particle::Electron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::AntiNeutrino(particleenergia*2.35E-7*ELECTRONMASS));  
+             particle_vector.push(Particle::Element(decay_particle,particleenergia));
+             particle_vector.push(Particle::Lepton(Lepton::Electron(particleenergia*(1.0-2.35E-7))));  
+             particle_vector.push(Particle::AntiLepton(AntiLepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));  
           } ,
    25  => {                    // B+  +  SF
              let rand = rand()>>54;
@@ -445,9 +451,9 @@ match x {
              let totalenergia = (self.amu()- daughter.amu())*931.49410242;
              let particleenergia = (daughter.amu()/self.amu())* totalenergia ;  
              energia = totalenergia - particleenergia ;
-              particle_vector.push(Particle::Element(decay_particle,particleenergia));
-              particle_vector.push(Particle::Positron(particleenergia*(1.0-2.35E-7)));  
-            particle_vector.push(Particle::Neutrino(particleenergia*2.35E-7*ELECTRONMASS));  
+             particle_vector.push(Particle::Element(decay_particle,particleenergia));
+             particle_vector.push(Particle::AntiLepton(AntiLepton::Electron(particleenergia*(1.0-2.35E-7))));  
+             particle_vector.push(Particle::Lepton(Lepton::ElectronNeutrino(particleenergia*2.35E-7*ELECTRONMASS)));       
           } ,
    26  => {                    // CD C14 
                    izotop.0-=6; izotop.1-=8;                        
