@@ -1,4 +1,8 @@
-
+//use Pion::
+use Pion::lepton::Lepton;
+use Pion::lepton::AntiLepton;
+use Pion::baryon::Baryon;
+use Pion::baryon::AntiBaryon;
 
 use crate::Nuclide ;
  pub const PROTONMASS   : f64 = 1.007276466621f64      ;
@@ -9,7 +13,7 @@ use crate::Nuclide ;
  pub const DEUTERONMASS : f64 = 2.01355338927343374    ;
  
  pub const NEUTRINOMASS : f64 = 1.288738236E-10        ;
-
+/*
 // Replace with Pion library
 #[derive(Debug,Clone)]
 pub enum Particle {
@@ -27,5 +31,18 @@ pub enum Particle {
       Triton(f64),
       Element(Nuclide,f64),
  }
+ */
+ #[derive(Debug,Clone)]
+ pub enum Particle{
+     Photon(f64),
+     Lepton(Lepton),
+     AntiLepton(AntiLepton),
+     Baryon(Baryon),
+     AntiBaryon(AntiBaryon),
+     Alpha(f64),
+     Deuteron(f64),
+     Triton(f64),
+     Element(Nuclide,f64),   
+ }
  
  
